@@ -5,12 +5,11 @@ use Moo::Role;
 requires qw( ppi_document debug format xtest _process_found_modules develop );
 
 use PPI;
-
-use version 0.9902;
 use Data::Printer;    # caller_info => 1;
 use Try::Tiny;
 
-our $VERSION = '0.27_13';
+use version;
+our $VERSION = '0.29_03';
 use constant {BLANK => q{ }, TRUE => 1, FALSE => 0, NONE => q{}, TWO => 2,
 	THREE => 3,};
 
@@ -25,7 +24,6 @@ sub xtests_use_module {
 	my @modules;
 	my @version_strings;
 
-
 # bug out if there is no Include for Module::Runtime found
 	return if $self->_is_module_runtime() eq FALSE;
 
@@ -416,12 +414,10 @@ sub _module_names_ppi_sl {
 
 	if ($ppi_sl->isa('PPI::Structure::List')) {
 
-#		p $ppi_sl;
 		state $previous_module = undef;
 		foreach my $ppi_se (@{$ppi_sl->{children}}) {
 			for ( 0..$#{$ppi_se->{children}}) {
 
-#p $ppi_se->{children}[$_];
 				if ( $ppi_se->{children}[$_]->isa('PPI::Token::Quote::Single')
 					|| $ppi_se->{children}[$_]->isa('PPI::Token::Quote::Double'))
 				{
@@ -430,7 +426,6 @@ sub _module_names_ppi_sl {
 					if ($module =~ m/\A[A-Z]/) {
 						warn 'found module - ' . $module if $self->debug;
 						push @$modules, $module;
-#						p $module;
 						p @$modules if $self->debug;
 						$previous_module = $module;
 					}
@@ -456,7 +451,7 @@ sub _module_names_ppi_sl {
 					try {
 						$self->{found_version}{$previous_module}
 							= $version_string if $previous_module;
-#						p $version_string;
+						p $version_string if $self->debug;
 						$previous_module = undef;
 					};
 				}
@@ -485,33 +480,8 @@ includes, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.27_13
+version: 0.29_03
 
-=head1 DESCRIPTION
-
-This scanner will look for the following formats or variations there in.
-
-=begin :list
-
-* use_module("Module::Name", x.xx)->new( ... );
-
-* require_module( 'Module::Name');
-
-* use_package_optimistically("Module::Name", x.xx)->new( ... );
-
-* my $abc = use_module("Module::Name", x.xx)->new( ... );
-
-* my $abc = use_package_optimistically("Module::Name", x.xx)->new( ... );
-
-* $abc = use_module("Module::Name", x.xx)->new( ... );
-
-* $abc = use_package_optimistically("Module::Name", x.xx)->new( ... );
-
-* return use_module( 'Module::Name', x,xx )->new( ... );
-
-* return use_package_optimisticall( 'Module::Name', x.xx )->new( ... );
-
-=end :list
 
 =head1 METHODS
 
@@ -534,6 +504,8 @@ Checking for the following, extracting module name and version strings.
   return use_module( 'Module::Name', x,xx )->new( ... );
   return use_package_optimisticall( 'Module::Name', x.xx )->new( ... );
 
+We also support the prefix C<Module::Runtime::...> in the above.
+
 =back
 
 =head1 AUTHOR
